@@ -4,19 +4,18 @@ from contextlib import AbstractAsyncContextManager
 
 from langgraph.graph.state import CompiledStateGraph
 
+from src.cli.bootstrap.initializer import initializer
 from src.cli.core.context import Context
-from src.cli.initializer import initializer
-from src.cli.interface.commands import CommandHandler
-from src.cli.interface.messages import MessageHandler
-from src.cli.interface.prompt import InteractivePrompt
-from src.cli.interface.renderer import Renderer
+from src.cli.dispatchers import CommandDispatcher, MessageDispatcher
 from src.cli.theme import console, theme
+from src.cli.ui.prompt import InteractivePrompt
+from src.cli.ui.renderer import Renderer
 from src.core.logging import get_logger
 
 logger = get_logger(__name__)
 
 
-class CLISession:
+class Session:
     """Main CLI session manager for interactive chat."""
 
     def __init__(
@@ -25,10 +24,10 @@ class CLISession:
     ):
         self.context = context
         self.renderer = Renderer()
-        self.command_handler = CommandHandler(self)
-        self.message_handler = MessageHandler(self)
+        self.command_dispatcher = CommandDispatcher(self)
+        self.message_dispatcher = MessageDispatcher(self)
         self.prompt = InteractivePrompt(
-            self.context, list(self.command_handler.commands.keys()), session=self
+            self.context, list(self.command_dispatcher.commands.keys()), session=self
         )
 
         # Set up mode change callback
@@ -42,6 +41,7 @@ class CLISession:
         self.running = False
         self.needs_reload = False
         self.prefilled_text: str | None = None
+        self.prefilled_reference_mapping: dict[str, str] = {}
 
     async def start(self, show_welcome: bool = True) -> None:
         """Start the interactive session."""
@@ -66,18 +66,16 @@ class CLISession:
 
         while self.running:
             try:
-                user_input = await self.prompt.get_input()
+                content, is_slash_command = await self.prompt.get_input()
 
-                if not user_input or not user_input.strip():
+                if not content:
                     continue
 
-                if user_input.startswith("/"):
-                    result = await self.command_handler.handle(user_input)
-                    if result:
-                        self.prefilled_text = result
+                if is_slash_command:
+                    await self.command_dispatcher.dispatch(content)
                     continue
 
-                await self.message_handler.handle(user_input)
+                await self.message_dispatcher.dispatch(content)
 
             except EOFError:
                 break
